/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <QtCore/QString>
#include <QtCore/QDebug>
#include <QtGui/QGraphicsScene>
#include <QtGui/QGraphicsPixmapItem>
#include "imageelement.h"
#include "reader.h"
#include "graphicsscene.h"

namespace
{
    const GraphicsElement::AttributeDetails ATTRIBUTES[ImageElement::ATTRIBUTE_COUNT] =
    {
     {"xpos", true},
     {"ypos", true},
     {"src", false}
    };
}

ImageElement::ImageElement(Reader* reader): GraphicsElement(reader)
{
    element_ = new QGraphicsPixmapItem();
}

bool ImageElement::setAttribute(QString const& name,
                                QString const& value)
{
    int intVal = 0;
    int attrId = -1;

    if((attrId = getAttribute(name, value, ATTRIBUTES, ATTRIBUTE_COUNT, intVal)) != -1)
    {
        Attribute attr = static_cast<Attribute>(attrId);

        switch(attr)
        {
        case XPOS:
            element_->setX(intVal);
            break;
        case YPOS:
            element_->setY(intVal);
            break;
        case SRC:
            return loadImage(value);
            break;

        default:
            qDebug() << "Unknown attribute: " << attr;
            return false;
        }

        return true;
    }
    else
    {
        return false;
    }
}

void ImageElement::addToScene(GraphicsScene* scene)
{
    scene->addItem(element_);
}

void ImageElement::update()
{
}

bool ImageElement::loadImage(QString const& name)
{
    QPixmap pixmap;
    QByteArray data;

    if(!readFile(name, data))
    {
        return false;
    }

    if(!pixmap.loadFromData(data))
    {
        setError("Invalid image file: " + name);
        return false;
    }

    element_->setPixmap(pixmap);

    return true;
}
