/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <QtGui/QWidget>
#include <QtCore/QString>
#include <QtCore/QDebug>
#include <QtXml/QDomNode>
#include <QtXml/QDomNodeList>
#include "themescreen.h"
#include "graphicselement.h"
#include "reader.h"

ThemeScreen::ThemeScreen(QWidget* parent): GraphicsScreen(parent)
{
}

bool ThemeScreen::load(QDomNode const& data, Reader* reader)
{
    QDomNodeList childNodes = data.childNodes();

    if(childNodes.size() == 0)
    {
        error_ = "No elements specified for " + data.nodeName();
        return false;
    }

    for(int i = 0; i < childNodes.size(); i++)
    {
        GraphicsElement* element = GraphicsElement::getElement(childNodes.at(i).nodeName(), reader);

        if(element == 0)
        {
            qDebug() << "Warning: invalid element: " << childNodes.at(i).nodeName();
            continue;
        }

        elements_.push_back(element);

        QDomNodeList options = childNodes.at(i).childNodes();

        for(int i = 0; i < options.size(); i++)
        {
            if(!element->setAttribute(options.at(i).nodeName(), options.at(i).toElement().text()))
            {
                qDebug() << "Warning: invalid option: " << options.at(i).nodeName();
            }
        }

        element->addToScene(getScene());

    }

    return true;
}

void ThemeScreen::update()
{
    for(int i = 0; i < elements_.size(); i++)
    {
        elements_.at(i)->update();
    }
}
